@@ -3,8 +3,8 @@ import re
 from django import template
 from django.template import TemplateSyntaxError
 import viewlet
-from viewlet.exceptions import ViewletException
-
+from viewlet.exceptions import UnknownViewlet
+from viewlet.loaders import mark_safe
 
 logger = logging.getLogger(__name__)
 register = template.Library()
@@ -13,16 +13,20 @@ kwarg_re = re.compile(r'(?:(\w+)=)?(.+)')
 
 class ViewletNode(template.Node):
 
-    def __init__(self, viewlet_name, args):
+    def __init__(self, viewlet_name, args, kwargs):
         self.viewlet_name = viewlet_name
         self.viewlet_args = args
+        self.viewlet_kwargs = kwargs
 
     def render(self, context):
         try:
             args = [arg.resolve(context) for arg in self.viewlet_args]
-            return viewlet.call(self.viewlet_name, context, *args)
-        except ViewletException as e:
+            kwargs = dict((key, value.resolve(context)) for key, value in self.viewlet_kwargs.iteritems())
+            template = viewlet.call(self.viewlet_name, context, *args, **kwargs)
+            return mark_safe(template)
+        except UnknownViewlet as e:
             logger.exception(e)
+            raise
 
 
 @register.tag(name='viewlet')
@@ -42,4 +46,4 @@ def viewlet_tag(parser, token):
         else:
             args.append(parser.compile_filter(value))
 
-    return ViewletNode(viewlet_name, args)
+    return ViewletNode(viewlet_name, args, kwargs)
